================
CSNG-Invariances
================


.. image:: https://img.shields.io/pypi/v/csng_invariances.svg
        :target: https://pypi.python.org/pypi/csng_invariances

.. image:: https://img.shields.io/travis/leeeeon4/csng_invariances.svg
        :target: https://travis-ci.com/leeeeon4/csng_invariances

.. image:: https://readthedocs.org/projects/csng-invariances/badge/?version=latest
        :target: https://csng-invariances.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Reimplementation of Kovacs 2021: Finding invariances in sensory coding through gradient methods. in PyTorch.


* Free software: MIT license
* Documentation: https://csng-invariances.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
